@@ -9,6 +9,8 @@ from .table_representation import Table
 from .table_representation import Column
 from .yaml_worker import YamlActionsWorker
 from .yaml_worker import YamlDataBaseWorker
+from sql import SQLite
+from sql import SQL
 
 __all__ = [
     'YamlDataBaseWorker',
@@ -23,5 +25,7 @@ __all__ = [
     'RemoveActionImpossibleError',
     'FileReadError',
     'InsertActionImpossibleError',
-    'convert_table_data_from_dict_to_table_obj'
+    'convert_table_data_from_dict_to_table_obj',
+    'SQL',
+    'SQLite'
 ]
\ No newline at end of file
